@@ -40,9 +40,14 @@
 #endif
 
 #ifdef _MSC_VER
-#pragma warning( push )
-#pragma warning( disable : 4290 )  /* C++ exception specification ignored except to indicate a function is not __declspec(nothrow)*/
-#pragma warning( disable : 4268 )  /* 'H5O_TOKEN_UNDEF_g': 'const' static/global data initialized with compiler generated default constructor fills the object with zeros */
+#pragma warning(push)
+#pragma warning(                                                               \
+    disable : 4290) /* C++ exception specification ignored except to indicate  \
+                       a function is not __declspec(nothrow)*/
+#pragma warning(                                                               \
+    disable : 4268) /* 'H5O_TOKEN_UNDEF_g': 'const' static/global data         \
+                       initialized with compiler generated default constructor \
+                       fills the object with zeros */
 #endif
 
 #include "libkea/KEACommon.h"
@@ -51,7 +56,7 @@
 #include "libkea/KEAAttributeTableInMem.h"
 
 #ifdef _MSC_VER
-#pragma warning( pop )
+#pragma warning(pop)
 #endif
 
 #endif /* GDAL_LIBKEA_HEADERS_H */
