@@ -105,7 +105,7 @@ PCIDSK::Create( std::string filename, int pixels, int lines,
     int  tilesize = PCIDSK_DEFAULT_TILE_SIZE;
     std::string oLinkFilename;
 
-    std::string oOrigOptions = options;
+    const std::string oOrigOptions = options;
     UCaseStr( options );
     for(auto & c : options)
     {
@@ -549,8 +549,8 @@ PCIDSK::Create( std::string filename, int pixels, int lines,
 /*      ourselves allow the creation to be 50% faster.                  */
 /* -------------------------------------------------------------------- */
         size_t nBufSize = 524288; // Number of 512 blocks for 256MB
-        char* puBuf = new char[nBufSize*512];
-        std::unique_ptr<char[]> oZeroAutoPtr(puBuf);
+        std::unique_ptr<char[]> oZeroAutoPtr(new char[nBufSize*512]);
+        char* puBuf = oZeroAutoPtr.get();
         std::memset(puBuf,0,nBufSize*512); //prezero
 
         uint64 nBlocksRest = image_data_size;
@@ -579,9 +579,7 @@ PCIDSK::Create( std::string filename, int pixels, int lines,
 /* -------------------------------------------------------------------- */
     oHandleAutoPtr.Close();
 
-    PCIDSKFile *file = Open( filename, "r+", interfaces );
-
-    std::unique_ptr<PCIDSKFile> oFileAutoPtr(file);
+    auto file = std::unique_ptr<PCIDSKFile>(Open( filename, "r+", interfaces ));
 
     if(oLinkFilename.size() > 64)
     {
@@ -614,9 +612,8 @@ PCIDSK::Create( std::string filename, int pixels, int lines,
             file->WriteToFile( ih.buffer, ih_offset, 1024 );
         }
 
-        oFileAutoPtr.reset(nullptr);
-        file = Open( filename, "r+", interfaces );
-        oFileAutoPtr.reset(file);
+        file.reset();
+        file.reset(Open( filename, "r+", interfaces ));
     }
 
 /* -------------------------------------------------------------------- */
@@ -633,7 +630,7 @@ PCIDSK::Create( std::string filename, int pixels, int lines,
     {
         file->SetMetadataValue( "_DBLayout", options );
 
-        CPCIDSKBlockFile oBlockFile(file);
+        CPCIDSKBlockFile oBlockFile(file.get());
 
         SysTileDir * poTileDir = oBlockFile.CreateTileDir();
 
@@ -693,7 +690,5 @@ PCIDSK::Create( std::string filename, int pixels, int lines,
         }
     }
 
-    oFileAutoPtr.release();
-
-    return file;
+    return file.release();
 }
