@@ -42,8 +42,6 @@
 #include "ogr_p.h"
 #include "ograpispy.h"
 
-CPL_CVSID("$Id$")
-
 /************************************************************************/
 /*                           OGRFeatureDefn()                           */
 /************************************************************************/
@@ -61,10 +59,11 @@ CPL_CVSID("$Id$")
  * need to be unique.
  */
 
-OGRFeatureDefn::OGRFeatureDefn( const char * pszName )
+OGRFeatureDefn::OGRFeatureDefn(const char *pszName)
 {
-    pszFeatureClassName = CPLStrdup( pszName );
-    apoGeomFieldDefn.emplace_back(cpl::make_unique<OGRGeomFieldDefn>("", wkbUnknown));
+    pszFeatureClassName = CPLStrdup(pszName);
+    apoGeomFieldDefn.emplace_back(
+        cpl::make_unique<OGRGeomFieldDefn>("", wkbUnknown));
 }
 
 /************************************************************************/
@@ -84,7 +83,7 @@ OGRFeatureDefn::OGRFeatureDefn( const char * pszName )
  * @return handle to the newly created feature definition.
  */
 
-OGRFeatureDefnH OGR_FD_Create( const char *pszName )
+OGRFeatureDefnH OGR_FD_Create(const char *pszName)
 
 {
     return OGRFeatureDefn::ToHandle(new OGRFeatureDefn(pszName));
@@ -97,14 +96,14 @@ OGRFeatureDefnH OGR_FD_Create( const char *pszName )
 OGRFeatureDefn::~OGRFeatureDefn()
 
 {
-    if( nRefCount != 0 )
+    if (nRefCount != 0)
     {
-        CPLDebug( "OGRFeatureDefn",
-                  "OGRFeatureDefn %s with a ref count of %d deleted!",
-                  pszFeatureClassName, nRefCount );
+        CPLDebug("OGRFeatureDefn",
+                 "OGRFeatureDefn %s with a ref count of %d deleted!",
+                 pszFeatureClassName, nRefCount);
     }
 
-    CPLFree( pszFeatureClassName );
+    CPLFree(pszFeatureClassName);
 }
 
 /************************************************************************/
@@ -120,7 +119,7 @@ OGRFeatureDefn::~OGRFeatureDefn()
  * @param hDefn handle to the feature definition to be destroyed.
  */
 
-void OGR_FD_Destroy( OGRFeatureDefnH hDefn )
+void OGR_FD_Destroy(OGRFeatureDefnH hDefn)
 
 {
     delete OGRFeatureDefn::FromHandle(hDefn);
@@ -139,7 +138,7 @@ void OGR_FD_Destroy( OGRFeatureDefnH hDefn )
 void OGRFeatureDefn::Release()
 
 {
-    if( Dereference() <= 0 )
+    if (Dereference() <= 0)
         delete this;
 }
 
@@ -155,7 +154,7 @@ void OGRFeatureDefn::Release()
  * @param hDefn handle to the feature definition to be released.
  */
 
-void OGR_FD_Release( OGRFeatureDefnH hDefn )
+void OGR_FD_Release(OGRFeatureDefnH hDefn)
 
 {
     OGRFeatureDefn::FromHandle(hDefn)->Release();
@@ -178,13 +177,13 @@ void OGR_FD_Release( OGRFeatureDefnH hDefn )
 OGRFeatureDefn *OGRFeatureDefn::Clone() const
 
 {
-    OGRFeatureDefn *poCopy = new OGRFeatureDefn( GetName() );
+    OGRFeatureDefn *poCopy = new OGRFeatureDefn(GetName());
 
     {
         const int nFieldCount = GetFieldCount();
         poCopy->apoFieldDefn.reserve(nFieldCount);
-        for( int i = 0; i < nFieldCount; i++ )
-            poCopy->AddFieldDefn( GetFieldDefn( i ) );
+        for (int i = 0; i < nFieldCount; i++)
+            poCopy->AddFieldDefn(GetFieldDefn(i));
     }
 
     {
@@ -192,8 +191,8 @@ OGRFeatureDefn *OGRFeatureDefn::Clone() const
         poCopy->DeleteGeomFieldDefn(0);
         const int nGeomFieldCount = GetGeomFieldCount();
         poCopy->apoGeomFieldDefn.reserve(nGeomFieldCount);
-        for( int i = 0; i < nGeomFieldCount; i++ )
-            poCopy->AddGeomFieldDefn( GetGeomFieldDefn( i ) );
+        for (int i = 0; i < nGeomFieldCount; i++)
+            poCopy->AddGeomFieldDefn(GetGeomFieldDefn(i));
     }
 
     return poCopy;
@@ -209,7 +208,7 @@ OGRFeatureDefn *OGRFeatureDefn::Clone() const
  * @param pszName feature definition name
  * @since GDAL 2.3
  */
-void OGRFeatureDefn::SetName( const char* pszName )
+void OGRFeatureDefn::SetName(const char *pszName)
 {
     CPLFree(pszFeatureClassName);
     pszFeatureClassName = CPLStrdup(pszName);
@@ -229,7 +228,7 @@ void OGRFeatureDefn::SetName( const char* pszName )
  * @return the name.  This name is internal and should not be modified, or
  * freed.
  */
-const char * OGRFeatureDefn::GetName() const
+const char *OGRFeatureDefn::GetName() const
 {
     return pszFeatureClassName;
 }
@@ -247,7 +246,7 @@ const char * OGRFeatureDefn::GetName() const
  * freed.
  */
 
-const char *OGR_FD_GetName( OGRFeatureDefnH hDefn )
+const char *OGR_FD_GetName(OGRFeatureDefnH hDefn)
 
 {
     return OGRFeatureDefn::FromHandle(hDefn)->GetName();
@@ -284,11 +283,11 @@ int OGRFeatureDefn::GetFieldCount() const
  * @return count of fields.
  */
 
-int OGR_FD_GetFieldCount( OGRFeatureDefnH hDefn )
+int OGR_FD_GetFieldCount(OGRFeatureDefnH hDefn)
 
 {
 #ifdef OGRAPISPY_ENABLED
-    if( bOGRAPISpyEnabled )
+    if (bOGRAPISpyEnabled)
         OGRAPISpy_FD_GetFieldCount(hDefn);
 #endif
 
@@ -310,10 +309,10 @@ int OGR_FD_GetFieldCount( OGRFeatureDefnH hDefn )
  * index.  This object should not be modified or freed by the application.
  */
 
-OGRFieldDefn *OGRFeatureDefn::GetFieldDefn( int iField )
+OGRFieldDefn *OGRFeatureDefn::GetFieldDefn(int iField)
 
 {
-    if( iField < 0 || iField >= GetFieldCount() )
+    if (iField < 0 || iField >= GetFieldCount())
     {
         CPLError(CE_Failure, CPLE_AppDefined, "Invalid index : %d", iField);
         return nullptr;
@@ -335,10 +334,10 @@ OGRFieldDefn *OGRFeatureDefn::GetFieldDefn( int iField )
  * @since GDAL 2.3
  */
 
-const OGRFieldDefn *OGRFeatureDefn::GetFieldDefn( int iField ) const
+const OGRFieldDefn *OGRFeatureDefn::GetFieldDefn(int iField) const
 
 {
-    if( iField < 0 || iField >= GetFieldCount() )
+    if (iField < 0 || iField >= GetFieldCount())
     {
         CPLError(CE_Failure, CPLE_AppDefined, "Invalid index : %d", iField);
         return nullptr;
@@ -365,15 +364,14 @@ const OGRFieldDefn *OGRFeatureDefn::GetFieldDefn( int iField ) const
  * index.  This object should not be modified or freed by the application.
  */
 
-OGRFieldDefnH OGR_FD_GetFieldDefn( OGRFeatureDefnH hDefn, int iField )
+OGRFieldDefnH OGR_FD_GetFieldDefn(OGRFeatureDefnH hDefn, int iField)
 
 {
-    OGRFieldDefnH hFieldDefnH =
-        OGRFieldDefn::ToHandle(
-            OGRFeatureDefn::FromHandle(hDefn)->GetFieldDefn(iField));
+    OGRFieldDefnH hFieldDefnH = OGRFieldDefn::ToHandle(
+        OGRFeatureDefn::FromHandle(hDefn)->GetFieldDefn(iField));
 
 #ifdef OGRAPISPY_ENABLED
-    if( bOGRAPISpyEnabled )
+    if (bOGRAPISpyEnabled)
         OGRAPISpy_FD_GetFieldDefn(hDefn, iField, hFieldDefnH);
 #endif
 
@@ -411,7 +409,7 @@ void OGRFeatureDefn::ReserveSpaceForFields(int nFieldCountIn)
  * @param poNewDefn the definition of the new field.
  */
 
-void OGRFeatureDefn::AddFieldDefn( const OGRFieldDefn * poNewDefn )
+void OGRFeatureDefn::AddFieldDefn(const OGRFieldDefn *poNewDefn)
 
 {
     apoFieldDefn.emplace_back(cpl::make_unique<OGRFieldDefn>(poNewDefn));
@@ -438,11 +436,11 @@ void OGRFeatureDefn::AddFieldDefn( const OGRFieldDefn * poNewDefn )
  * @param hNewField handle to the new field definition.
  */
 
-void OGR_FD_AddFieldDefn( OGRFeatureDefnH hDefn, OGRFieldDefnH hNewField )
+void OGR_FD_AddFieldDefn(OGRFeatureDefnH hDefn, OGRFieldDefnH hNewField)
 
 {
-    OGRFeatureDefn::FromHandle(hDefn)->
-        AddFieldDefn( OGRFieldDefn::FromHandle(hNewField));
+    OGRFeatureDefn::FromHandle(hDefn)->AddFieldDefn(
+        OGRFieldDefn::FromHandle(hNewField));
 }
 
 /************************************************************************/
@@ -465,10 +463,10 @@ void OGR_FD_AddFieldDefn( OGRFeatureDefnH hDefn, OGRFieldDefnH hNewField )
  * @since OGR 1.9.0
  */
 
-OGRErr OGRFeatureDefn::DeleteFieldDefn( int iField )
+OGRErr OGRFeatureDefn::DeleteFieldDefn(int iField)
 
 {
-    if( iField < 0 || iField >= GetFieldCount() )
+    if (iField < 0 || iField >= GetFieldCount())
         return OGRERR_FAILURE;
 
     apoFieldDefn.erase(apoFieldDefn.begin() + iField);
@@ -496,7 +494,7 @@ OGRErr OGRFeatureDefn::DeleteFieldDefn( int iField )
  * @since OGR 1.9.0
  */
 
-OGRErr OGR_FD_DeleteFieldDefn( OGRFeatureDefnH hDefn, int iField )
+OGRErr OGR_FD_DeleteFieldDefn(OGRFeatureDefnH hDefn, int iField)
 
 {
     return OGRFeatureDefn::FromHandle(hDefn)->DeleteFieldDefn(iField);
@@ -525,19 +523,19 @@ OGRErr OGR_FD_DeleteFieldDefn( OGRFeatureDefnH hDefn, int iField )
  * @since OGR 1.9.0
  */
 
-OGRErr OGRFeatureDefn::ReorderFieldDefns( const int* panMap )
+OGRErr OGRFeatureDefn::ReorderFieldDefns(const int *panMap)
 
 {
     const int nFieldCount = GetFieldCount();
-    if( nFieldCount == 0 )
+    if (nFieldCount == 0)
         return OGRERR_NONE;
 
     const OGRErr eErr = OGRCheckPermutation(panMap, nFieldCount);
-    if( eErr != OGRERR_NONE )
+    if (eErr != OGRERR_NONE)
         return eErr;
 
     std::vector<std::unique_ptr<OGRFieldDefn>> apoFieldDefnNew(nFieldCount);
-    for( int i = 0; i < nFieldCount; i++ )
+    for (int i = 0; i < nFieldCount; i++)
     {
         apoFieldDefnNew[i] = std::move(apoFieldDefn[panMap[i]]);
     }
@@ -570,7 +568,7 @@ OGRErr OGRFeatureDefn::ReorderFieldDefns( const int* panMap )
  * @since OGR 2.1.0
  */
 
-OGRErr OGR_FD_ReorderFieldDefns( OGRFeatureDefnH hDefn, const int* panMap )
+OGRErr OGR_FD_ReorderFieldDefns(OGRFeatureDefnH hDefn, const int *panMap)
 
 {
     return OGRFeatureDefn::FromHandle(hDefn)->ReorderFieldDefns(panMap);
@@ -610,11 +608,11 @@ int OGRFeatureDefn::GetGeomFieldCount() const
  * @since GDAL 1.11
  */
 
-int OGR_FD_GetGeomFieldCount( OGRFeatureDefnH hDefn )
+int OGR_FD_GetGeomFieldCount(OGRFeatureDefnH hDefn)
 
 {
 #ifdef OGRAPISPY_ENABLED
-    if( bOGRAPISpyEnabled )
+    if (bOGRAPISpyEnabled)
         OGRAPISpy_FD_GetGeomFieldCount(hDefn);
 #endif
 
@@ -639,10 +637,10 @@ int OGR_FD_GetGeomFieldCount( OGRFeatureDefnH hDefn )
  * @since GDAL 1.11
  */
 
-OGRGeomFieldDefn *OGRFeatureDefn::GetGeomFieldDefn( int iGeomField )
+OGRGeomFieldDefn *OGRFeatureDefn::GetGeomFieldDefn(int iGeomField)
 
 {
-    if( iGeomField < 0 || iGeomField >= GetGeomFieldCount() )
+    if (iGeomField < 0 || iGeomField >= GetGeomFieldCount())
     {
         CPLError(CE_Failure, CPLE_AppDefined, "Invalid index : %d", iGeomField);
         return nullptr;
@@ -665,10 +663,10 @@ OGRGeomFieldDefn *OGRFeatureDefn::GetGeomFieldDefn( int iGeomField )
  * @since GDAL 2.3
  */
 
-const OGRGeomFieldDefn *OGRFeatureDefn::GetGeomFieldDefn( int iGeomField ) const
+const OGRGeomFieldDefn *OGRFeatureDefn::GetGeomFieldDefn(int iGeomField) const
 
 {
-    if( iGeomField < 0 || iGeomField >= GetGeomFieldCount() )
+    if (iGeomField < 0 || iGeomField >= GetGeomFieldCount())
     {
         CPLError(CE_Failure, CPLE_AppDefined, "Invalid index : %d", iGeomField);
         return nullptr;
@@ -697,17 +695,14 @@ const OGRGeomFieldDefn *OGRFeatureDefn::GetGeomFieldDefn( int iGeomField ) const
  * @since GDAL 1.11
  */
 
-OGRGeomFieldDefnH OGR_FD_GetGeomFieldDefn( OGRFeatureDefnH hDefn,
-                                           int iGeomField )
+OGRGeomFieldDefnH OGR_FD_GetGeomFieldDefn(OGRFeatureDefnH hDefn, int iGeomField)
 
 {
-    OGRGeomFieldDefnH hGeomField =
-        OGRGeomFieldDefn::ToHandle(
-            OGRFeatureDefn::FromHandle(hDefn)->
-                GetGeomFieldDefn(iGeomField));
+    OGRGeomFieldDefnH hGeomField = OGRGeomFieldDefn::ToHandle(
+        OGRFeatureDefn::FromHandle(hDefn)->GetGeomFieldDefn(iGeomField));
 
 #ifdef OGRAPISPY_ENABLED
-    if( bOGRAPISpyEnabled )
+    if (bOGRAPISpyEnabled)
         OGRAPISpy_FD_GetGeomFieldDefn(hDefn, iGeomField, hGeomField);
 #endif
 
@@ -739,9 +734,10 @@ OGRGeomFieldDefnH OGR_FD_GetGeomFieldDefn( OGRFeatureDefnH hDefn,
  * @since GDAL 1.11
  */
 
-void OGRFeatureDefn::AddGeomFieldDefn( const OGRGeomFieldDefn * poNewDefn )
+void OGRFeatureDefn::AddGeomFieldDefn(const OGRGeomFieldDefn *poNewDefn)
 {
-    apoGeomFieldDefn.emplace_back(cpl::make_unique<OGRGeomFieldDefn>(poNewDefn));
+    apoGeomFieldDefn.emplace_back(
+        cpl::make_unique<OGRGeomFieldDefn>(poNewDefn));
 }
 
 /**
@@ -760,7 +756,8 @@ void OGRFeatureDefn::AddGeomFieldDefn( const OGRGeomFieldDefn * poNewDefn )
  * @since GDAL 3.4
  */
 
-void OGRFeatureDefn::AddGeomFieldDefn( std::unique_ptr<OGRGeomFieldDefn>&& poNewDefn )
+void OGRFeatureDefn::AddGeomFieldDefn(
+    std::unique_ptr<OGRGeomFieldDefn> &&poNewDefn)
 {
     apoGeomFieldDefn.emplace_back(std::move(poNewDefn));
 }
@@ -789,8 +786,8 @@ void OGRFeatureDefn::AddGeomFieldDefn( std::unique_ptr<OGRGeomFieldDefn>&& poNew
  * @since GDAL 1.11
  */
 
-void OGR_FD_AddGeomFieldDefn( OGRFeatureDefnH hDefn,
-                              OGRGeomFieldDefnH hNewGeomField )
+void OGR_FD_AddGeomFieldDefn(OGRFeatureDefnH hDefn,
+                             OGRGeomFieldDefnH hNewGeomField)
 
 {
     OGRFeatureDefn::FromHandle(hDefn)->AddGeomFieldDefn(
@@ -818,10 +815,10 @@ void OGR_FD_AddGeomFieldDefn( OGRFeatureDefnH hDefn,
  * @since GDAL 1.11
  */
 
-OGRErr OGRFeatureDefn::DeleteGeomFieldDefn( int iGeomField )
+OGRErr OGRFeatureDefn::DeleteGeomFieldDefn(int iGeomField)
 
 {
-    if( iGeomField < 0 || iGeomField >= GetGeomFieldCount() )
+    if (iGeomField < 0 || iGeomField >= GetGeomFieldCount())
         return OGRERR_FAILURE;
 
     apoGeomFieldDefn.erase(apoGeomFieldDefn.begin() + iGeomField);
@@ -852,11 +849,10 @@ OGRErr OGRFeatureDefn::DeleteGeomFieldDefn( int iGeomField )
  * @since GDAL 1.11
  */
 
-OGRErr OGR_FD_DeleteGeomFieldDefn( OGRFeatureDefnH hDefn, int iGeomField )
+OGRErr OGR_FD_DeleteGeomFieldDefn(OGRFeatureDefnH hDefn, int iGeomField)
 
 {
-    return OGRFeatureDefn::FromHandle(hDefn)->
-        DeleteGeomFieldDefn(iGeomField);
+    return OGRFeatureDefn::FromHandle(hDefn)->DeleteGeomFieldDefn(iGeomField);
 }
 
 /************************************************************************/
@@ -876,15 +872,15 @@ OGRErr OGR_FD_DeleteGeomFieldDefn( OGRFeatureDefnH hDefn, int iGeomField )
  * @return the geometry field index, or -1 if no match found.
  */
 
-int OGRFeatureDefn::GetGeomFieldIndex( const char * pszGeomFieldName ) const
+int OGRFeatureDefn::GetGeomFieldIndex(const char *pszGeomFieldName) const
 
 {
     const int nGeomFieldCount = GetGeomFieldCount();
-    for( int i = 0; i < nGeomFieldCount; i++ )
+    for (int i = 0; i < nGeomFieldCount; i++)
     {
-        const OGRGeomFieldDefn* poGFldDefn = GetGeomFieldDefn(i);
-        if( poGFldDefn != nullptr && EQUAL(pszGeomFieldName,
-                                        poGFldDefn->GetNameRef() ) )
+        const OGRGeomFieldDefn *poGFldDefn = GetGeomFieldDefn(i);
+        if (poGFldDefn != nullptr &&
+            EQUAL(pszGeomFieldName, poGFldDefn->GetNameRef()))
             return i;
     }
 
@@ -909,17 +905,17 @@ int OGRFeatureDefn::GetGeomFieldIndex( const char * pszGeomFieldName ) const
  * @return the geometry field index, or -1 if no match found.
  */
 
-int OGR_FD_GetGeomFieldIndex( OGRFeatureDefnH hDefn,
-                              const char *pszGeomFieldName )
+int OGR_FD_GetGeomFieldIndex(OGRFeatureDefnH hDefn,
+                             const char *pszGeomFieldName)
 
 {
 #ifdef OGRAPISPY_ENABLED
-    if( bOGRAPISpyEnabled )
+    if (bOGRAPISpyEnabled)
         OGRAPISpy_FD_GetGeomFieldIndex(hDefn, pszGeomFieldName);
 #endif
 
-    return OGRFeatureDefn::FromHandle(hDefn)->
-        GetGeomFieldIndex(pszGeomFieldName);
+    return OGRFeatureDefn::FromHandle(hDefn)->GetGeomFieldIndex(
+        pszGeomFieldName);
 }
 
 /************************************************************************/
@@ -946,14 +942,14 @@ int OGR_FD_GetGeomFieldIndex( OGRFeatureDefnH hDefn,
  */
 OGRwkbGeometryType OGRFeatureDefn::GetGeomType() const
 {
-    if( GetGeomFieldCount() == 0 )
+    if (GetGeomFieldCount() == 0)
         return wkbNone;
-    const OGRGeomFieldDefn* poGFldDefn = GetGeomFieldDefn(0);
-    if( poGFldDefn == nullptr )
+    const OGRGeomFieldDefn *poGFldDefn = GetGeomFieldDefn(0);
+    if (poGFldDefn == nullptr)
         return wkbNone;
     OGRwkbGeometryType eType = poGFldDefn->GetType();
-    if( eType == (wkbUnknown | wkb25DBitInternalUse) &&
-        CPLTestBool(CPLGetConfigOption("QGIS_HACK", "NO")) )
+    if (eType == (/*wkbUnknown |*/ wkb25DBitInternalUse) &&
+        CPLTestBool(CPLGetConfigOption("QGIS_HACK", "NO")))
         eType = wkbUnknown;
     return eType;
 }
@@ -972,17 +968,16 @@ OGRwkbGeometryType OGRFeatureDefn::GetGeomType() const
  * @return the base type for all geometry related to this definition.
  */
 
-OGRwkbGeometryType OGR_FD_GetGeomType( OGRFeatureDefnH hDefn )
+OGRwkbGeometryType OGR_FD_GetGeomType(OGRFeatureDefnH hDefn)
 
 {
-    OGRwkbGeometryType eType =
-        OGRFeatureDefn::FromHandle(hDefn)->GetGeomType();
-    if( OGR_GT_IsNonLinear(eType) && !OGRGetNonLinearGeometriesEnabledFlag() )
+    OGRwkbGeometryType eType = OGRFeatureDefn::FromHandle(hDefn)->GetGeomType();
+    if (OGR_GT_IsNonLinear(eType) && !OGRGetNonLinearGeometriesEnabledFlag())
     {
         eType = OGR_GT_GetLinear(eType);
     }
 #ifdef OGRAPISPY_ENABLED
-    if( bOGRAPISpyEnabled )
+    if (bOGRAPISpyEnabled)
         OGRAPISpy_FD_GetGeomType(hDefn);
 #endif
 
@@ -1008,20 +1003,20 @@ OGRwkbGeometryType OGR_FD_GetGeomType( OGRFeatureDefnH hDefn )
  * @param eNewType the new type to assign.
  */
 
-void OGRFeatureDefn::SetGeomType( OGRwkbGeometryType eNewType )
+void OGRFeatureDefn::SetGeomType(OGRwkbGeometryType eNewType)
 
 {
     const int nGeomFieldCount = GetGeomFieldCount();
-    if( nGeomFieldCount > 0 )
+    if (nGeomFieldCount > 0)
     {
-        if( nGeomFieldCount == 1 && eNewType == wkbNone )
+        if (nGeomFieldCount == 1 && eNewType == wkbNone)
             DeleteGeomFieldDefn(0);
         else
             GetGeomFieldDefn(0)->SetType(eNewType);
     }
-    else if( eNewType != wkbNone )
+    else if (eNewType != wkbNone)
     {
-        OGRGeomFieldDefn oGeomFieldDefn( "", eNewType );
+        OGRGeomFieldDefn oGeomFieldDefn("", eNewType);
         AddGeomFieldDefn(&oGeomFieldDefn);
     }
 }
@@ -1048,7 +1043,7 @@ void OGRFeatureDefn::SetGeomType( OGRwkbGeometryType eNewType )
  * @param eType the new type to assign.
  */
 
-void OGR_FD_SetGeomType( OGRFeatureDefnH hDefn, OGRwkbGeometryType eType )
+void OGR_FD_SetGeomType(OGRFeatureDefnH hDefn, OGRwkbGeometryType eType)
 
 {
     OGRFeatureDefn::FromHandle(hDefn)->SetGeomType(eType);
@@ -1087,7 +1082,7 @@ void OGR_FD_SetGeomType( OGRFeatureDefnH hDefn, OGRwkbGeometryType eType )
  * @return the updated reference count.
  */
 
-int OGR_FD_Reference( OGRFeatureDefnH hDefn )
+int OGR_FD_Reference(OGRFeatureDefnH hDefn)
 
 {
     return OGRFeatureDefn::FromHandle(hDefn)->Reference();
@@ -1121,7 +1116,7 @@ int OGR_FD_Reference( OGRFeatureDefnH hDefn )
  * @return the updated reference count.
  */
 
-int OGR_FD_Dereference( OGRFeatureDefnH hDefn )
+int OGR_FD_Dereference(OGRFeatureDefnH hDefn)
 
 {
     return OGRFeatureDefn::FromHandle(hDefn)->Dereference();
@@ -1156,7 +1151,7 @@ int OGR_FD_Dereference( OGRFeatureDefnH hDefn )
  * @return the current reference count.
  */
 
-int OGR_FD_GetReferenceCount( OGRFeatureDefnH hDefn )
+int OGR_FD_GetReferenceCount(OGRFeatureDefnH hDefn)
 
 {
     return OGRFeatureDefn::FromHandle(hDefn)->GetReferenceCount();
@@ -1179,14 +1174,14 @@ int OGR_FD_GetReferenceCount( OGRFeatureDefnH hDefn )
  * @return the field index, or -1 if no match found.
  */
 
-int OGRFeatureDefn::GetFieldIndex( const char * pszFieldName ) const
+int OGRFeatureDefn::GetFieldIndex(const char *pszFieldName) const
 
 {
     const int nFieldCount = GetFieldCount();
-    for( int i = 0; i < nFieldCount; i++ )
+    for (int i = 0; i < nFieldCount; i++)
     {
-        const OGRFieldDefn* poFDefn = GetFieldDefn(i);
-        if( poFDefn != nullptr && EQUAL(pszFieldName, poFDefn->GetNameRef() ) )
+        const OGRFieldDefn *poFDefn = GetFieldDefn(i);
+        if (poFDefn != nullptr && EQUAL(pszFieldName, poFDefn->GetNameRef()))
             return i;
     }
 
@@ -1200,22 +1195,23 @@ int OGRFeatureDefn::GetFieldIndex( const char * pszFieldName ) const
 /**
  * \brief Find field by name, in a case sensitive way.
  *
- * The field index of the first field matching the passed field name is returned.
+ * The field index of the first field matching the passed field name is
+ * returned.
  *
  * @param pszFieldName the field name to search for.
  *
  * @return the field index, or -1 if no match found.
  */
 
-int OGRFeatureDefn::GetFieldIndexCaseSensitive( const char * pszFieldName ) const
+int OGRFeatureDefn::GetFieldIndexCaseSensitive(const char *pszFieldName) const
 
 {
     const int nFieldCount = GetFieldCount();
-    for( int i = 0; i < nFieldCount; i++ )
+    for (int i = 0; i < nFieldCount; i++)
     {
-        const OGRFieldDefn* poFDefn = GetFieldDefn(i);
-        if( poFDefn != nullptr &&
-            strcmp(pszFieldName, poFDefn->GetNameRef() ) == 0 )
+        const OGRFieldDefn *poFDefn = GetFieldDefn(i);
+        if (poFDefn != nullptr &&
+            strcmp(pszFieldName, poFDefn->GetNameRef()) == 0)
         {
             return i;
         }
@@ -1241,16 +1237,15 @@ int OGRFeatureDefn::GetFieldIndexCaseSensitive( const char * pszFieldName ) cons
  * @return the field index, or -1 if no match found.
  */
 
-int OGR_FD_GetFieldIndex( OGRFeatureDefnH hDefn, const char *pszFieldName )
+int OGR_FD_GetFieldIndex(OGRFeatureDefnH hDefn, const char *pszFieldName)
 
 {
 #ifdef OGRAPISPY_ENABLED
-    if( bOGRAPISpyEnabled )
+    if (bOGRAPISpyEnabled)
         OGRAPISpy_FD_GetFieldIndex(hDefn, pszFieldName);
 #endif
 
-    return
-        OGRFeatureDefn::FromHandle(hDefn)->GetFieldIndex(pszFieldName);
+    return OGRFeatureDefn::FromHandle(hDefn)->GetFieldIndex(pszFieldName);
 }
 
 /************************************************************************/
@@ -1272,10 +1267,10 @@ int OGR_FD_GetFieldIndex( OGRFeatureDefnH hDefn, const char *pszFieldName )
 
 int OGRFeatureDefn::IsGeometryIgnored() const
 {
-    if( GetGeomFieldCount() == 0 )
+    if (GetGeomFieldCount() == 0)
         return FALSE;
-    const OGRGeomFieldDefn* poGFldDefn = GetGeomFieldDefn(0);
-    if( poGFldDefn == nullptr )
+    const OGRGeomFieldDefn *poGFldDefn = GetGeomFieldDefn(0);
+    if (poGFldDefn == nullptr)
         return FALSE;
     return poGFldDefn->IsIgnored();
 }
@@ -1298,7 +1293,7 @@ int OGRFeatureDefn::IsGeometryIgnored() const
  * @return ignore state
  */
 
-int OGR_FD_IsGeometryIgnored( OGRFeatureDefnH hDefn )
+int OGR_FD_IsGeometryIgnored(OGRFeatureDefnH hDefn)
 {
     return OGRFeatureDefn::FromHandle(hDefn)->IsGeometryIgnored();
 }
@@ -1319,12 +1314,12 @@ int OGR_FD_IsGeometryIgnored( OGRFeatureDefnH hDefn )
  * @param bIgnore ignore state
  */
 
-void OGRFeatureDefn::SetGeometryIgnored( int bIgnore )
+void OGRFeatureDefn::SetGeometryIgnored(int bIgnore)
 {
-    if( GetGeomFieldCount() > 0 )
+    if (GetGeomFieldCount() > 0)
     {
-        OGRGeomFieldDefn* poGFldDefn = GetGeomFieldDefn(0);
-        if( poGFldDefn != nullptr )
+        OGRGeomFieldDefn *poGFldDefn = GetGeomFieldDefn(0);
+        if (poGFldDefn != nullptr)
             poGFldDefn->SetIgnored(bIgnore);
     }
 }
@@ -1346,9 +1341,9 @@ void OGRFeatureDefn::SetGeometryIgnored( int bIgnore )
  * @param bIgnore ignore state
  */
 
-void OGR_FD_SetGeometryIgnored( OGRFeatureDefnH hDefn, int bIgnore )
+void OGR_FD_SetGeometryIgnored(OGRFeatureDefnH hDefn, int bIgnore)
 {
-    OGRFeatureDefn::FromHandle(hDefn)->SetGeometryIgnored( bIgnore );
+    OGRFeatureDefn::FromHandle(hDefn)->SetGeometryIgnored(bIgnore);
 }
 
 /************************************************************************/
@@ -1380,7 +1375,7 @@ void OGR_FD_SetGeometryIgnored( OGRFeatureDefnH hDefn, int bIgnore )
  * @return ignore state
  */
 
-int OGR_FD_IsStyleIgnored( OGRFeatureDefnH hDefn )
+int OGR_FD_IsStyleIgnored(OGRFeatureDefnH hDefn)
 {
     return OGRFeatureDefn::FromHandle(hDefn)->IsStyleIgnored();
 }
@@ -1414,7 +1409,7 @@ int OGR_FD_IsStyleIgnored( OGRFeatureDefnH hDefn )
  * @param bIgnore ignore state
  */
 
-void OGR_FD_SetStyleIgnored( OGRFeatureDefnH hDefn, int bIgnore )
+void OGR_FD_SetStyleIgnored(OGRFeatureDefnH hDefn, int bIgnore)
 {
     OGRFeatureDefn::FromHandle(hDefn)->SetStyleIgnored(CPL_TO_BOOL(bIgnore));
 }
@@ -1427,10 +1422,10 @@ void OGR_FD_SetStyleIgnored( OGRFeatureDefnH hDefn, int bIgnore )
  * @param pszName name
  * @return new feature definition object.
  */
-OGRFeatureDefn *OGRFeatureDefn::CreateFeatureDefn( const char *pszName )
+OGRFeatureDefn *OGRFeatureDefn::CreateFeatureDefn(const char *pszName)
 
 {
-    return new OGRFeatureDefn( pszName );
+    return new OGRFeatureDefn(pszName);
 }
 
 /************************************************************************/
@@ -1440,7 +1435,7 @@ OGRFeatureDefn *OGRFeatureDefn::CreateFeatureDefn( const char *pszName )
 /** Destroy a feature definition.
  * @param poDefn feature definition.
  */
-void OGRFeatureDefn::DestroyFeatureDefn( OGRFeatureDefn *poDefn )
+void OGRFeatureDefn::DestroyFeatureDefn(OGRFeatureDefn *poDefn)
 
 {
     delete poDefn;
@@ -1457,30 +1452,30 @@ void OGRFeatureDefn::DestroyFeatureDefn( OGRFeatureDefn *poDefn )
  * @return TRUE if the feature definition is identical to the other one.
  */
 
-int OGRFeatureDefn::IsSame( const OGRFeatureDefn * poOtherFeatureDefn ) const
+int OGRFeatureDefn::IsSame(const OGRFeatureDefn *poOtherFeatureDefn) const
 {
     const int nFieldCount = GetFieldCount();
     const int nGeomFieldCount = GetGeomFieldCount();
-    if( strcmp(GetName(), poOtherFeatureDefn->GetName()) == 0 &&
+    if (strcmp(GetName(), poOtherFeatureDefn->GetName()) == 0 &&
         nFieldCount == poOtherFeatureDefn->GetFieldCount() &&
-        nGeomFieldCount == poOtherFeatureDefn->GetGeomFieldCount() )
+        nGeomFieldCount == poOtherFeatureDefn->GetGeomFieldCount())
     {
-        for( int i = 0; i < nFieldCount; i++ )
+        for (int i = 0; i < nFieldCount; i++)
         {
-            const OGRFieldDefn* poFldDefn = GetFieldDefn(i);
-            const OGRFieldDefn* poOtherFldDefn =
+            const OGRFieldDefn *poFldDefn = GetFieldDefn(i);
+            const OGRFieldDefn *poOtherFldDefn =
                 poOtherFeatureDefn->GetFieldDefn(i);
-            if( !poFldDefn->IsSame(poOtherFldDefn) )
+            if (!poFldDefn->IsSame(poOtherFldDefn))
             {
                 return FALSE;
             }
         }
-        for( int i = 0; i < nGeomFieldCount; i++ )
+        for (int i = 0; i < nGeomFieldCount; i++)
         {
-            const OGRGeomFieldDefn* poGFldDefn = GetGeomFieldDefn(i);
-            const OGRGeomFieldDefn* poOtherGFldDefn =
+            const OGRGeomFieldDefn *poGFldDefn = GetGeomFieldDefn(i);
+            const OGRGeomFieldDefn *poOtherGFldDefn =
                 poOtherFeatureDefn->GetGeomFieldDefn(i);
-            if( !poGFldDefn->IsSame(poOtherGFldDefn) )
+            if (!poGFldDefn->IsSame(poOtherGFldDefn))
             {
                 return FALSE;
             }
@@ -1505,13 +1500,13 @@ int OGRFeatureDefn::IsSame( const OGRFeatureDefn * poOtherFeatureDefn ) const
  * @since OGR 1.11
  */
 
-int OGR_FD_IsSame( OGRFeatureDefnH hFDefn, OGRFeatureDefnH hOtherFDefn )
+int OGR_FD_IsSame(OGRFeatureDefnH hFDefn, OGRFeatureDefnH hOtherFDefn)
 {
-    VALIDATE_POINTER1( hFDefn, "OGR_FD_IsSame", FALSE );
-    VALIDATE_POINTER1( hOtherFDefn, "OGR_FD_IsSame", FALSE );
+    VALIDATE_POINTER1(hFDefn, "OGR_FD_IsSame", FALSE);
+    VALIDATE_POINTER1(hOtherFDefn, "OGR_FD_IsSame", FALSE);
 
-    return OGRFeatureDefn::FromHandle(hFDefn)->
-        IsSame(OGRFeatureDefn::FromHandle(hOtherFDefn));
+    return OGRFeatureDefn::FromHandle(hFDefn)->IsSame(
+        OGRFeatureDefn::FromHandle(hOtherFDefn));
 }
 
 /************************************************************************/
@@ -1535,26 +1530,24 @@ int OGR_FD_IsSame( OGRFeatureDefnH hFDefn, OGRFeatureDefnH hOtherFDefn )
  * @since GDAL 2.3
  */
 
-std::vector<int> OGRFeatureDefn::ComputeMapForSetFrom( const OGRFeatureDefn* poSrcFDefn,
-                                                       bool bForgiving ) const
+std::vector<int>
+OGRFeatureDefn::ComputeMapForSetFrom(const OGRFeatureDefn *poSrcFDefn,
+                                     bool bForgiving) const
 {
     std::map<CPLString, int> oMapNameToTargetFieldIndex;
     std::map<CPLString, int> oMapNameToTargetFieldIndexUC;
     const int nFieldCount = GetFieldCount();
-    for( int i = 0; i < nFieldCount; i++ )
+    for (int i = 0; i < nFieldCount; i++)
     {
-#ifdef __MINGW64__
-        const OGRFieldDefn* poFldDefn = GetFieldDefn(i);
-        if( poFldDefn == nullptr ) continue;
-#else
-        const OGRFieldDefn* poFldDefn = CPLAssertNotNull(GetFieldDefn(i)); /* Make GCC-8 -Wnull-dereference happy */
-#endif
-        const char* pszName = poFldDefn->GetNameRef();
+        const OGRFieldDefn *poFldDefn = GetFieldDefn(i);
+        if (poFldDefn == nullptr)
+            continue;
+        const char *pszName = poFldDefn->GetNameRef();
 
         // In the insane case where there are several matches, arbitrarily
         // decide for the first one (preserve past behavior)
-        if( oMapNameToTargetFieldIndex.find(pszName) ==
-                                        oMapNameToTargetFieldIndex.end() )
+        if (oMapNameToTargetFieldIndex.find(pszName) ==
+            oMapNameToTargetFieldIndex.end())
         {
             oMapNameToTargetFieldIndex[pszName] = i;
         }
@@ -1562,39 +1555,33 @@ std::vector<int> OGRFeatureDefn::ComputeMapForSetFrom( const OGRFeatureDefn* poS
     std::vector<int> aoMapSrcToTargetIdx;
     const int nSrcFieldCount = poSrcFDefn->GetFieldCount();
     aoMapSrcToTargetIdx.resize(nSrcFieldCount);
-    for( int i = 0; i < nSrcFieldCount; i++ )
+    for (int i = 0; i < nSrcFieldCount; i++)
     {
-#ifdef __MINGW64__
-        const OGRFieldDefn* poSrcFldDefn = poSrcFDefn->GetFieldDefn(i);
-        if( poSrcFldDefn == nullptr ) continue;
-#else
-        const OGRFieldDefn* poSrcFldDefn = CPLAssertNotNull(poSrcFDefn->GetFieldDefn(i)); /* Make GCC-8 -Wnull-dereference happy */
-#endif
-        const char* pszSrcName = poSrcFldDefn->GetNameRef();
+        const OGRFieldDefn *poSrcFldDefn = poSrcFDefn->GetFieldDefn(i);
+        if (poSrcFldDefn == nullptr)
+            continue;
+        const char *pszSrcName = poSrcFldDefn->GetNameRef();
 
         auto oIter = oMapNameToTargetFieldIndex.find(pszSrcName);
-        if( oIter == oMapNameToTargetFieldIndex.end() )
+        if (oIter == oMapNameToTargetFieldIndex.end())
         {
             // Build case insensitive map only if needed
-            if( oMapNameToTargetFieldIndexUC.empty() )
+            if (oMapNameToTargetFieldIndexUC.empty())
             {
-                for( int j = 0; j < nFieldCount; j++ )
+                for (int j = 0; j < nFieldCount; j++)
                 {
-#ifdef __MINGW64__
-                    const OGRFieldDefn* poFldDefn = GetFieldDefn(j);
-                    if( poFldDefn == nullptr ) continue;
-#else
-                    const OGRFieldDefn* poFldDefn = CPLAssertNotNull(GetFieldDefn(j)); /* Make GCC-8 -Wnull-dereference happy */
-#endif
-                    oMapNameToTargetFieldIndexUC[
-                        CPLString(poFldDefn->GetNameRef()).toupper()] = j;
+                    const OGRFieldDefn *poFldDefn = GetFieldDefn(j);
+                    if (poFldDefn == nullptr)
+                        continue;
+                    oMapNameToTargetFieldIndexUC
+                        [CPLString(poFldDefn->GetNameRef()).toupper()] = j;
                 }
             }
             oIter = oMapNameToTargetFieldIndexUC.find(
                 CPLString(pszSrcName).toupper());
-            if( oIter == oMapNameToTargetFieldIndexUC.end() )
+            if (oIter == oMapNameToTargetFieldIndexUC.end())
             {
-                if( !bForgiving )
+                if (!bForgiving)
                 {
                     return std::vector<int>();
                 }
