@@ -342,7 +342,8 @@ OGRErr OGRGeometryCollection::addGeometry(const OGRGeometry *poNewGeom)
  * Some subclasses of OGRGeometryCollection restrict the types of geometry
  * that can be added, and may return an error.  Ownership of the passed
  * geometry is taken by the container rather than cloning as addGeometry()
- * does.
+ * does, but only if the method is successful. If the method fails, ownership
+ * still belongs to the caller.
  *
  * This method is the same as the C function OGR_G_AddGeometryDirectly().
  *
@@ -375,6 +376,33 @@ OGRErr OGRGeometryCollection::addGeometryDirectly(OGRGeometry *poNewGeom)
     return OGRERR_NONE;
 }
 
+/************************************************************************/
+/*                            addGeometry()                             */
+/************************************************************************/
+
+/**
+ * \brief Add a geometry directly to the container.
+ *
+ * Some subclasses of OGRGeometryCollection restrict the types of geometry
+ * that can be added, and may return an error.
+ *
+ * There is no SFCOM analog to this method.
+ *
+ * @param geom geometry to add to the container.
+ *
+ * @return OGRERR_NONE if successful, or OGRERR_UNSUPPORTED_GEOMETRY_TYPE if
+ * the geometry type is illegal for the type of geometry container.
+ */
+
+OGRErr OGRGeometryCollection::addGeometry(std::unique_ptr<OGRGeometry> geom)
+{
+    OGRGeometry *poGeom = geom.release();
+    OGRErr eErr = addGeometryDirectly(poGeom);
+    if (eErr != OGRERR_NONE)
+        delete poGeom;
+    return eErr;
+}
+
 /************************************************************************/
 /*                           removeGeometry()                           */
 /************************************************************************/
@@ -449,6 +477,7 @@ size_t OGRGeometryCollection::WkbSize() const
 /*                       importFromWkbInternal()                        */
 /************************************************************************/
 
+//! @cond Doxygen_Suppress
 OGRErr OGRGeometryCollection::importFromWkbInternal(
     const unsigned char *pabyData, size_t nSize, int nRecLevel,
     OGRwkbVariant eWkbVariant, size_t &nBytesConsumedOut)
@@ -464,15 +493,19 @@ OGRErr OGRGeometryCollection::importFromWkbInternal(
         return OGRERR_CORRUPT_DATA;
     }
 
-    nGeomCount = 0;
     OGRwkbByteOrder eByteOrder = wkbXDR;
     size_t nDataOffset = 0;
-    OGRErr eErr = importPreambleOfCollectionFromWkb(
-        pabyData, nSize, nDataOffset, eByteOrder, 9, nGeomCount, eWkbVariant);
+    int nGeomCountNew = 0;
+    OGRErr eErr = importPreambleOfCollectionFromWkb(pabyData, nSize,
+                                                    nDataOffset, eByteOrder, 9,
+                                                    nGeomCountNew, eWkbVariant);
 
     if (eErr != OGRERR_NONE)
         return eErr;
 
+    CPLAssert(nGeomCount == 0);
+    nGeomCount = nGeomCountNew;
+
     // coverity[tainted_data]
     papoGeoms = static_cast<OGRGeometry **>(
         VSI_CALLOC_VERBOSE(sizeof(void *), nGeomCount));
@@ -553,6 +586,7 @@ OGRErr OGRGeometryCollection::importFromWkbInternal(
 
     return OGRERR_NONE;
 }
+//! @endcond
 
 /************************************************************************/
 /*                           importFromWkb()                            */
@@ -1127,7 +1161,8 @@ OGRBoolean OGRGeometryCollection::IsEmpty() const
 /*                       assignSpatialReference()                       */
 /************************************************************************/
 
-void OGRGeometryCollection::assignSpatialReference(OGRSpatialReference *poSR)
+void OGRGeometryCollection::assignSpatialReference(
+    const OGRSpatialReference *poSR)
 {
     OGRGeometry::assignSpatialReference(poSR);
     for (auto &&poSubGeom : *this)
